import os
import sys


def resource_path(relative_path):
    if getattr(sys, '_MEIPASS', False):
        base_path = sys._MEIPASS
    else:
        base_path = os.path.abspath(".")
    return os.path.join(base_path, relative_path)



import ast
import astunparse  # 需要安装：pip install astunparse

import ast
import astunparse


def replace_var_ast(file_path, var_name, new_value):
    with open(file_path, 'r', encoding='utf-8') as f:
        code = f.read()

    # 解析为 AST
    tree = ast.parse(code)

    # 标志变量是否找到
    var_found = False

    # 遍历 AST，找到目标变量并修改
    for node in ast.walk(tree):
        if isinstance(node, ast.Assign):
            for target in node.targets:
                if isinstance(target, ast.Name) and target.id == var_name:
                    # 修改变量的值
                    node.value = ast.parse(repr(new_value)).body[0].value
                    var_found = True

    # 如果变量不存在，则在文件末尾添加新的赋值语句
    if not var_found:
        # 创建新的赋值节点
        new_assign = ast.Assign(
            targets=[ast.Name(id=var_name, ctx=ast.Store())],
            value=ast.parse(repr(new_value)).body[0].value
        )

        # 将新节点添加到模块体的末尾
        if isinstance(tree, ast.Module):
            tree.body.append(new_assign)
        else:
            # 如果不是模块，创建一个新模块包含原始代码和新赋值
            new_tree = ast.Module(body=[tree, new_assign])
            tree = new_tree

    # 将 AST 转换回代码
    new_code = astunparse.unparse(tree)

    with open(file_path, 'w', encoding='utf-8') as f:
        f.write(new_code)



import base64


def file_to_base64(file_path):
    with open(file_path, 'rb') as file:
        file_content = file.read()
        base64_content = base64.b64encode(file_content)
        return base64_content.decode('utf-8')


def base64_to_file(base64_str, output_path):
    file_content = base64.b64decode(base64_str.encode('utf-8'))
    with open(output_path, 'wb') as file:
        file.write(file_content)


def base64_to_bytes(base64_str):
    return base64.b64decode(base64_str)



from haige_py import __version__
from setuptools import setup, find_packages

setup(
    name="haige_py",
    version=__version__,
    author="喜欢吃白米饭",
    author_email="gzhehai@foxmail.com",
    description="江湖海哥的常用 python 封装通用包。",
    # long_description=open("README.md").read(),
    # long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=[
        "astunparse>=1.6.3"
    ],
    python_requires=">=3.6",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
